@@ -11,7 +11,8 @@ from copy import deepcopy
 
 from pygments.token import String, Token
 
-from purdy.parser import CodeLine, CodePart, token_is_a, parse_source
+from purdy.parser import (CodeLine, CodePart, token_is_a, parse_source,
+    PurdyLexer)
 
 # ===========================================================================
 # Animation Steps
@@ -83,10 +84,12 @@ class Subprocess:
         result = subprocess.run(args, stdout=subprocess.PIPE,
             stderr=subprocess.PIPE, universal_newlines=True)
 
+        lexer = PurdyLexer.factory_from_name('con')
+
         new_lines = []
         for row in result.stdout.split('\n'):
             part = CodePart(Token.Generic.Output, row)
-            new_lines.append( CodeLine([part, ], None) )
+            new_lines.append( CodeLine([part, ], lexer) )
 
         self.undo_position = len(self.code_box.listing.lines) + 1
         self.undo_size = len(new_lines)
@@ -105,9 +108,18 @@ class ReplaceRows(BaseEditStep):
         self.position = position
 
     def __str__(self):
-        return f'steps.ReplaceRow("{self.trunc_lines}" @ {self.position})'
+        return f'steps.ReplaceRows("{self.trunc_lines}" @ {self.position})'
 
     def render_step(self):
+        real_position = self.code_box.listing.positive_position(self.position)
+        box_length = len(self.code_box.listing.lines)
+        size = len(self.lines)
+        if real_position + size > box_length + 1:
+            raise AttributeError( ('Replacement happens in place. You cannot '
+                'replace outside the code_box. You are attempting to '
+                f'overwrite {size} lines at position {real_position} in a '
+                f'code_box that only has {box_length} lines') )
+
         self.undo_lines = self.code_box.listing.copy_lines(self.position,
             self.undo_size)
 
