@@ -25,11 +25,8 @@ class Code:
                        content. See :class:`purdy.parser.LexerContainer` for a
                        list of available lexers.
 
-    :param lexer_holder: if lexer_name is "custom" this parameter is expected
-                         to contain a purdy.parser.LexerHolder object.
-
-    :param palette: name of colourizer palette to use during colouring,
-                    defaults to 'code', which should handle most cases.
+    :param purdy_lexer: if lexer_name is "custom" this parameter is expected
+                         to contain a purdy.parser.PurdyLexer object.
     """
 
     def __init__(self, filename='', text='', lexer_name='detect', 
@@ -96,7 +93,7 @@ class Code:
         :param content: content to replace it with 
         """
         lines = self.source.split('\n')
-        lines[line_no + 1] = content
+        lines[line_no - 1] = content
         self.source = '\n'.join(lines)
         return self
 
@@ -109,8 +106,8 @@ class Code:
         :param content: content to replace with 
         """
         lines = self.source.split('\n')
-        lines[line_no + 1] = lines[line_no + 1][:pos - 1]
-        lines[line_no + 1] += content
+        lines[line_no - 1] = lines[line_no - 1][:pos - 1]
+        lines[line_no - 1] += content
         self.source = '\n'.join(lines)
         return self
 
